import { W3 } from './W3';
export declare class TestRPC {
    private w3;
    /**
     *
     */
    constructor(w3?: W3);
    /**
     * Snapshot the state of the blockchain at the current block. Takes no parameters.
     * Returns the integer id of the snapshot created.
     */
    snapshot(): Promise<string>;
    /**
     * Revert the state of the blockchain to a previous snapshot.
     * Takes a single parameter, which is the snapshot id to revert to.
     * If no snapshot id is passed it will revert to the latest snapshot. Returns true.
     */
    revert(snapshotId?: string): Promise<boolean>;
    /**
     * Jump forward in time. Takes one parameter, which is the amount of time to increase in seconds.
     * Returns the total time adjustment, in seconds.
     */
    increaseTime(seconds: number): Promise<number>;
    /**
     * Beware that due to the need of calling two separate testrpc methods and rpc calls overhead
     * it's hard to increase time precisely to a target point so design your test to tolerate
     * small fluctuations from time to time.
     *
     * @param target time in seconds
     */
    increaseTimeTo(target: number): Promise<number>;
    /**
     * Force a block to be mined. Takes no parameters. Mines a block independent of whether or not mining is started or stopped.
     */
    mine(): Promise<void>;
    advanceToBlock(blockNumber: number): Promise<void>;
}
