import { BigNumber } from 'bignumber.js';
import { W3, SoltsiceContract } from '..';
/**
 * MultiSigWallet API
 */
export declare class MultiSigWallet extends SoltsiceContract {
    static readonly artifacts: any;
    static readonly bytecodeHash: string | undefined;
    static new(deploymentParams: W3.TX.TxParams, ctorParams?: {
        _owners: string[];
        _required: BigNumber | number;
    }, w3?: W3, link?: SoltsiceContract[], privateKey?: string): Promise<MultiSigWallet>;
    static at(address: string | object, w3?: W3): Promise<MultiSigWallet>;
    static deployed(w3?: W3): Promise<MultiSigWallet>;
    static newData(ctorParams?: {
        _owners: string[];
        _required: BigNumber | number;
    }, w3?: W3): string;
    protected constructor(deploymentParams: string | W3.TX.TxParams | object, ctorParams?: {
        _owners: string[];
        _required: BigNumber | number;
    }, w3?: W3, link?: SoltsiceContract[]);
    owners(_0: BigNumber | number, txParams?: W3.TX.TxParams): Promise<string>;
    isOwner(_0: string, txParams?: W3.TX.TxParams): Promise<boolean>;
    confirmations(_0: BigNumber | number, _1: string, txParams?: W3.TX.TxParams): Promise<boolean>;
    transactions(_0: BigNumber | number, txParams?: W3.TX.TxParams): Promise<any>;
    transactionCount(txParams?: W3.TX.TxParams): Promise<BigNumber>;
    MAX_OWNER_COUNT(txParams?: W3.TX.TxParams): Promise<BigNumber>;
    required(txParams?: W3.TX.TxParams): Promise<BigNumber>;
    addOwner: ((owner: string, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((owner: string, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (owner: string, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (owner: string) => Promise<string>;
    } & {
        estimateGas: (owner: string) => Promise<number>;
    };
    removeOwner: ((owner: string, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((owner: string, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (owner: string, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (owner: string) => Promise<string>;
    } & {
        estimateGas: (owner: string) => Promise<number>;
    };
    replaceOwner: ((owner: string, newOwner: string, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((owner: string, newOwner: string, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (owner: string, newOwner: string, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (owner: string, newOwner: string) => Promise<string>;
    } & {
        estimateGas: (owner: string, newOwner: string) => Promise<number>;
    };
    changeRequirement: ((_required: number | BigNumber, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((_required: number | BigNumber, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (_required: number | BigNumber, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (_required: number | BigNumber) => Promise<string>;
    } & {
        estimateGas: (_required: number | BigNumber) => Promise<number>;
    };
    submitTransaction: ((destination: string, value: number | BigNumber, data: string, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((destination: string, value: number | BigNumber, data: string, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (destination: string, value: number | BigNumber, data: string, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (destination: string, value: number | BigNumber, data: string) => Promise<string>;
    } & {
        estimateGas: (destination: string, value: number | BigNumber, data: string) => Promise<number>;
    };
    confirmTransaction: ((transactionId: number | BigNumber, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((transactionId: number | BigNumber, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (transactionId: number | BigNumber, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (transactionId: number | BigNumber) => Promise<string>;
    } & {
        estimateGas: (transactionId: number | BigNumber) => Promise<number>;
    };
    revokeConfirmation: ((transactionId: number | BigNumber, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((transactionId: number | BigNumber, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (transactionId: number | BigNumber, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (transactionId: number | BigNumber) => Promise<string>;
    } & {
        estimateGas: (transactionId: number | BigNumber) => Promise<number>;
    };
    executeTransaction: ((transactionId: number | BigNumber, txParams?: W3.TX.TxParams | undefined, privateKey?: string | undefined) => Promise<W3.TX.TransactionResult>) & {
        sendTransaction: ((transactionId: number | BigNumber, txParams?: W3.TX.TxParams | undefined) => Promise<string>) & {
            sendSigned: (transactionId: number | BigNumber, privateKey: string, txParams?: W3.TX.TxParams | undefined, nonce?: number | undefined) => Promise<string>;
        };
    } & {
        data: (transactionId: number | BigNumber) => Promise<string>;
    } & {
        estimateGas: (transactionId: number | BigNumber) => Promise<number>;
    };
    isConfirmed(transactionId: BigNumber | number, txParams?: W3.TX.TxParams): Promise<boolean>;
    getConfirmationCount(transactionId: BigNumber | number, txParams?: W3.TX.TxParams): Promise<BigNumber>;
    getTransactionCount(pending: boolean, executed: boolean, txParams?: W3.TX.TxParams): Promise<BigNumber>;
    getOwners(txParams?: W3.TX.TxParams): Promise<string[]>;
    getConfirmations(transactionId: BigNumber | number, txParams?: W3.TX.TxParams): Promise<string[]>;
    getTransactionIds(from: BigNumber | number, to: BigNumber | number, pending: boolean, executed: boolean, txParams?: W3.TX.TxParams): Promise<BigNumber[]>;
}
